@@ -1,4 +1,4 @@
 from . import main
 
 if __name__ == "__main__":
-    main.entrypoint()
+    main.main()
