@@ -1,7 +1,8 @@
-from typing import Tuple, List, NamedTuple, Dict
-from enum import Enum
-from arms.utils.common import captitalize
 import re
+from enum import Enum
+from typing import Dict, List, NamedTuple
+
+from arms.utils.common import captitalize
 
 
 class WordStyle(Enum):
